#!/usr/bin/python
# -*- coding: utf-8 -*-
# title           : _LaLiga_matchdays_RF
# python_version  : Python 3.7.0
# ==============================================================================
# ==============================================================================
'''                           _LaLiga_matchdays                             '''
# ==============================================================================
# ==============================================================================
import requests
import time  # sleep
import requests
from bs4 import BeautifulSoup
import re
import _laliga_match as matchfile
import _laliga_standings as standings
import _laliga_teams as teamslist
from pymongo import MongoClient
from elasticsearch import Elasticsearch
import pprint

'''------------------------------------------------------------------------------------------------------------------------------'''


def cleanhtml(raw_html):
    cleanr = re.compile('<.*?>')
    cleantext = re.sub(cleanr, '', raw_html)
    return cleantext


def composed_team_name(line):
    line = line.replace('Rayo Vallecano', 'Rayo-Vallecano') \
        .replace('Real Madrid', 'Real-Madrid') \
        .replace('Real Valladolid', 'Valladolid') \
        .replace('Real Betis', 'Betis') \
        .replace('Real Sociedad', 'Real-Sociedad') \
        .replace('R. Sociedad', 'Real-Sociedad') \
        .replace('Atlético Madrid', 'Atlético-Madrid') \
        .replace('Atlético Osasuna', 'Osasuna') \
        .replace('Las Palmas', 'Las-Palmas') \
        .replace('Granada CF', 'Granada') \
        .replace('Real Sporting', 'Sporting') \
        .replace('Real Zaragoza', 'Zaragoza') \
        .replace('Racing', 'Racing-Santander') \
        .replace('Real Murcia', 'Murcia') \
        .replace('Real Oviedo', 'Real-Oviedo') \
        .replace('CF Extremadura', 'CF-Extremadura') \
        .replace('Mérida CP', 'Mérida-CP') \
        .replace('CD Logroñés', 'CD-Logroñés') \
        .replace('Real Burgos CF', 'Burgos') \
        .replace('Gimnàstic Tarragona', 'Gimnàstic-Tarragona') \
        .replace('CD Castellón', 'CD-Castellón') \
        .replace('CD Málaga', 'Málaga') \
        .replace('Almeria AD', 'Almería') \
        .replace(' *', '')
    if line == 'Atlético':
        line = line.replace('Atlético', 'Atlético-Madrid')
    if line == 'Athletic':
        line = line.replace('Athletic', 'Athletic-Bilbao')
    if line == 'Sporting':
        line = line.replace('Sporting', 'Sporting-Gijón')
    return line


def encode_match_url(url):
    re_find_year = re.match(r'.*([1-3][0-9]{3})', url)
    url = 'LaLiga' + re_find_year.group(1)
    return url


#### MONGO CONNECTION ####

def mongo_connect_standings(dictionary):
    mongo_client = MongoClient('localhost', 27017)
    mongo_db = mongo_client['laliga_database']
    mongo_collection = mongo_db['laliga_standings']
    mongo_collection.insert_one(dictionary)


def mongo_connect_matchdata(dictionary):
    mongo_client = MongoClient('localhost', 27017)
    mongo_db = mongo_client['laliga_database']
    mongo_collection = mongo_db['laliga_matchdata_v3']
    mongo_collection.insert_one(dictionary)


#### ALL SEASONS ####

def get_seasons():
    # seasons urls
    url_seasons = 'http://www.resultados-futbol.com/primera'
    url_seasons_req = requests.get(url_seasons)
    soup_seasons = BeautifulSoup(url_seasons_req.content, 'html.parser')
    desplega_temporadas = str(soup_seasons.find(id='desplega_temporadas'))
    seasons_list_raw = desplega_temporadas.split('\n')
    # seasons 1929-2018
    seasons_list = list()

    for season in seasons_list_raw:
        if season.find('<a href="') != -1:
            season = season[season.find(
                '<a href="') + len('<a href="'):season.find('">')]
            if season != '':
                seasons_list.append(season)
    return seasons_list


#### MATCHDAYS ####

def get_matchdays(seasons_list):
    # seasons dictionary
    seasons_dict = {}
    # matchdays
    for season in seasons_list:
        url_matchdays_req = requests.get(season)
        soup_matchdays = BeautifulSoup(
            url_matchdays_req.content, 'html.parser')
        desplega_jornadas = str(soup_matchdays.find(id='desplega_jornadas'))
        matchdays_list_raw = desplega_jornadas.split('<li')
        matchdays_list = list()
        matchdays_list_url = list()
        season_name = season[season.find(
            'http://www.resultados-futbol.com/') + len('http://www.resultados-futbol.com/'):]
        for matchday in matchdays_list_raw:
            if matchday.find('<a href="') != -1:
                matchday = matchday[matchday.find(
                    '<a href="') + len('<a href="'):matchday.find('">Jornada')]
                matchdays_list.append(matchday)
                matchday_url = matchday[matchday.find('/') + 1:]
                matchday_url = season + matchday_url[matchday_url.find('/'):]
                matchdays_list_url.append(matchday_url)
                seasons_dict[season_name] = matchdays_list_url
    return seasons_dict


#### ONE DICT PER SEASON ####

def get_standings_dict(season_matchdays_dict, seasonid):
    standings_dict = {}
    standings_dict['season'] = seasonid
    for current_season in season_matchdays_dict.keys():
        for matchday in season_matchdays_dict[current_season]:
            # find matchday integer & encode matchday
            matchday_encode = 'matchday_' + \
                              re.findall('\d+', matchday[matchday.rfind('/') + 1:])[0]
            standings_dict[matchday_encode] = standings.get_standings(
                matchday, seasonid)
            ####  INFO  ####
            print(matchday_encode + ' --> OK')
    return standings_dict


#### ONE DICT PER MATCHDAY ####

def get_standings(season_matchdays_dict, seasonid):
    for current_season in season_matchdays_dict.keys():
        for matchday in season_matchdays_dict[current_season]:
            # find matchday integer & encode matchday
            matchday_encode = 'matchday_' + \
                              re.findall('\d+', matchday[matchday.rfind('/') + 1:])[0]
            standings_dict = standings.get_standings_byteam(
                matchday, matchday_encode, seasonid)
            # insert into mongo
            # mongo_connect_standings(standings_dict)
            ####  INFO  ####
            print(matchday_encode + ' --> OK')
    return standings_dict


#### INSERT STANDINGS INTO MONGODB ####

def insert_standings_mongodb():
    # all seasons
    all_seasons_list = get_seasons()
    # all_seasons_list.append('http://www.resultados-futbol.com/primera2019')
    all_seasons_list.insert(0, 'http://www.resultados-futbol.com/primera2019')
    seasons_sampl = all_seasons_list[:1]
    print(seasons_sampl)
    for seas in seasons_sampl:
        season_list = list()
        season_list.append(seas)
        ####  INFO  ####
        print('STARTING ' + encode_match_url(season_list[0]))
        # seasons matchdays
        matchdays_dict = get_matchdays(season_list)
        get_standings(matchdays_dict, encode_match_url(season_list[0]))
        ####  INFO  ####
        print('SEASON ' + encode_match_url(season_list[0]) + ' --> OK')


#### INSERT MATCH DATA INTO MONGODB ####

def get_matchdays_matchdata():
    # teams list
    laliga_teams = teamslist.get_teams_list()
    # all seasons
    all_seasons_list = get_seasons()
    all_seasons_list.insert(0, 'http://www.resultados-futbol.com/primera2019')
    # seasons_sampl = all_seasons_list[3:4]21
    seasons_sampl = all_seasons_list[20:21] # 2019 - 2000
    # seasons_sampl = all_seasons_list[20:21] # 2019 - 2000
    print(seasons_sampl)
    for matchdays in seasons_sampl:
        print('\n' + matchdays + '\n')
        season_num = re.findall('\d', matchdays[matchdays.rfind('/')+1:])
        season_num = ''.join(season_num)
        matchdays_url_req = requests.get(matchdays)
        matchdays_soup = BeautifulSoup(matchdays_url_req.content, 'html.parser')

        matchdays_list = str(matchdays_soup.find_all('div', {'id': 'desplega_jornadas'})[0])[
                         str(matchdays_soup.find_all('div', {'id': 'desplega_jornadas'})[0]).find('<a href="'):].split(
            '<a href="')
        for matchdays_num in matchdays_list[:]:
            if len(matchdays_num) > 0:
                matchdays_num = matchdays_num[:matchdays_num.find('"')]
                matchdays_num_url = 'http://www.resultados-futbol.com' + matchdays_num
                matchdays_num_num = matchdays_num_url[matchdays_num_url.rfind('/')+1:]
                matchdays_num_num = re.findall('\d', matchdays_num_num)
                matchdays_num_num = ''.join(matchdays_num_num)
                print(matchdays_num_url)
                matchdays_url_num_req = requests.get(matchdays_num_url)
                matchdays_num_soup = BeautifulSoup(matchdays_url_num_req.content, 'html.parser')
                matchdays_events = matchdays_num_soup.find_all('tr', {'class': 'vevent'})
                for match in matchdays_events:
                    match = str(match)
                    # team1
                    match_team1 = match[match.find('<td class="equipo1">'):]
                    match_team1 = composed_team_name(
                        cleanhtml(match_team1[:match_team1.find('</td>')])[1:])
                    # team2
                    match_team2 = match[match.find('<td class="equipo2">'):]
                    match_team2 = composed_team_name(
                        cleanhtml(match_team2[:match_team2.find('</td>')])[1:])
                    # date
                    match_date_rfc822 = match[match.find(
                        '<td class="fecha" data-date="') + len('<td class="fecha" data-date="'):]
                    match_date_rfc822 = match_date_rfc822[:match_date_rfc822.find('"')]
                    # event url
                    match_url = match[match.find(
                        '<a class="url" href="') + len('<a class="url" href="'):]
                    match_url = 'http://www.resultados-futbol.com' + \
                                match_url[:match_url.find('">')]
                    # event status
                    match_status = match[
                                   match.find('<span class="fecha-status ">') + len('<span class="fecha-status ">'):]
                    match_status = match_status[:match_status.find('</span>')]

                    ### GET MATCH DATA ###
                    # match_url != 'http://www.resultados-futbol.com/partido/Barcelona/Sevilla/2017':
                    match_dict = matchfile.get_matchdata(match_url, match_team1, match_team2, match_date_rfc822, matchdays_num_num, season_num)
                    if match_dict != 'NO DATA':   
                        # check for new teams
                        if match_dict['match_team1'] not in laliga_teams:
                            laliga_teams.append(match_dict['match_team1'])
                            print('New team added: ' + match_dict['match_team1'])
                        if match_dict['match_team2'] not in laliga_teams:
                            laliga_teams.append(match_dict['match_team2'])
                            print('New team added: ' + match_dict['match_team2'])
                        print(match_dict)
                        # print("\nteam1: " + match_team1)
                        # print("team2: " + match_team2)
                        # print(match_date_rfc822)
                        # insert into mongo
                        mongo_connect_matchdata(match_dict)
                        print('ok')
                        # # print(match_dict['match_team1']+'\t'+match_dict['match_team2']+'\n')
                        # print(match_dict)
                        # print(match_status)
                        # print(match_dict['match_id']+'\t'+match_dict['match_score'])
                        # print(match_dict['match_team1'] + ': ' + str(match_dict['match_team1_goals']))
                        # print(match_dict['match_team1_goals_info'])
                        # print(match_dict['match_team1_goal_penalty_info'])
                        # print(match_dict['match_team1_goal_own_info'])
                        # print(match_dict['match_team1_goal_own2_info'])
                        # print(match_dict['match_team1_goal_freekick_info'])
                        # print()
                        # print(match_dict['match_team2'] + ': ' + str(match_dict['match_team2_goals']))
                        # print(match_dict['match_team2_goals_info'])
                        # print(match_dict['match_team2_goal_penalty_info'])
                        # print(match_dict['match_team2_goal_own_info'])
                        # print(match_dict['match_team2_goal_own2_info'])
                        # print(match_dict['match_team2_goal_freekick_info'])
                        # print(match_dict['match_team2_align_main'])
                        # print(match_dict['match_team2_align_sup'])
                        # print()
                        # print(match_dict['match_team1']+':')
                        # print(match_dict['match_team1_penalty_missed_info'])
                        # print(match_dict['match_team2'] + ':')
                        # print(match_dict['match_team2_penalty_saved_info'])
                        # print(match_dict['match_team2_penalty_saved2_info'])
                        # print(match_dict['match_team2_penalty_missed_info'])
                        # print(match_dict['match_team1_goal_cancelled_info'])
                        # print(match_dict['match_team1_goal_freekick_info'])
                        # print(match_dict['match_team1_penalty_saved_info'])
                        # print(match_dict['match_team1_penalty_missed_info'])
                        # print(match_dict['match_team2_goals_info'])
                        # print(match_dict['match_team2_goal_penalty_info'])
                        # print(match_dict['match_team2_goal_own_info'])
                        # print(match_dict['match_team2_goal_cancelled_info'])
                        # print(match_dict['match_team2_goal_freekick_info'])
                        # print(match_dict['match_team2_penalty_saved_info'])
                        # print(match_dict['match_team2_penalty_missed_info'])
                        # pp = pprint.PrettyPrinter(indent=2)
                        # pp.pprint(match_dict)
                    else:
                        print('ERROR')
                        print(match_url)


#### EXEC ####

#insert_standings_mongodb()
get_matchdays_matchdata()
