#!/usr/bin/python
# -*- coding: utf-8 -*-
# title           : laliga_standings
# python_version  : Python 3.7.0
# ==============================================================================
# ==============================================================================
'''                            laliga_standings                              '''
# ==============================================================================
# ==============================================================================
import requests
import time  # sleep
import requests
import bs4
import re
import yaml  # pretty print
import datetime
import json
from pymongo import MongoClient

'''------------------------------------------------------------------------------------------------------------------------------'''


def cleanhtml(raw_html):
    cleanr = re.compile('<.*?>')
    cleantext = re.sub(cleanr, '', raw_html)
    return cleantext


def composed_team_name(line):
    line = line.replace('Rayo Vallecano', 'Rayo-Vallecano') \
        .replace('Real Madrid', 'Real-Madrid') \
        .replace('Real Valladolid', 'Valladolid') \
        .replace('Real Betis', 'Betis') \
        .replace('Real Sociedad', 'Real-Sociedad') \
        .replace('R. Sociedad', 'Real-Sociedad') \
        .replace('Atlético Madrid', 'Atlético-Madrid') \
        .replace('Atlético Osasuna', 'Osasuna') \
        .replace('Las Palmas', 'Las-Palmas') \
        .replace('Granada CF', 'Granada') \
        .replace('Real Sporting', 'Sporting') \
        .replace('Real Zaragoza', 'Zaragoza') \
        .replace('Racing', 'Racing-Santander') \
        .replace('Real Murcia', 'Murcia') \
        .replace('Real Oviedo', 'Real-Oviedo') \
        .replace('CF Extremadura', 'CF-Extremadura') \
        .replace('Mérida CP', 'Mérida-CP') \
        .replace('CD Logroñés', 'CD-Logroñés') \
        .replace('Real Burgos CF', 'Burgos') \
        .replace('Gimnàstic Tarragona', 'Gimnàstic-Tarragona') \
        .replace('CD Castellón', 'CD-Castellón') \
        .replace('CD Málaga', 'Málaga') \
        .replace('Almeria AD', 'Almería') \
        .replace(' *', '')
    if line == 'Atlético':
        line = line.replace('Atlético', 'Atlético-Madrid')
    if line == 'Athletic':
        line = line.replace('Athletic', 'Athletic-Bilbao')
    if line == 'Sporting':
        line = line.replace('Sporting', 'Sporting-Gijón')
    return line


#### MONGO CONNECTION ####

def mongo_connect_standings(dictionary):
    mongo_client = MongoClient('localhost', 27017)
    mongo_db = mongo_client['laliga_database']
    mongo_collection = mongo_db['laliga_standings_2019']
    mongo_collection.insert_one(dictionary)


def get_standings(url, matchday_encode, seasonid):
    season = seasonid[-4:]
    season_past = int(season)-1
    season = str(season_past)+'/'+str(season)
    matchday = re.findall('\d', matchday_encode)
    matchday = ''.join(matchday)

    url_standings_req = requests.get(url)
    status = str(url_standings_req.status_code)
    # check status
    if status != '200':
        print()
        print('STATUS ERROR')
        print()
    else:
        pos = 1
        it = 0
        soup_standings = bs4.BeautifulSoup(url_standings_req.content, 'html.parser')
        '''STANDINGS LIST WITH INDEX'''
        standings_list = soup_standings.find(id='col-clasificacion')
        standings_raw = standings_list.find_all('a')
        standings = {}
        for s in standings_raw:
            s_clean = cleanhtml(str(s))
            standings.update({pos: s_clean})
            pos = pos + 1
        '''ALL STANDINGS INFO'''
        standings_info = standings_list.find_all('tr')
        del standings_info[0]
        standings_dict = {}
        standings_dict['season'] = season
        standings_dict['matchday'] = int(matchday)
        for t in standings_info:
            t_clean = cleanhtml(str(t))
            pattern_deletefreespace = re.compile(r'\s+')
            t_separated = re.sub(pattern_deletefreespace, ' ', t_clean)
            t_composed_teams = composed_team_name(t_separated)
            t_list = t_composed_teams.split()
            position = 'pos_' + t_list[0]
            standings_dict[position] = {
                'position': int(t_list[0]),
                'team_name': str(t_list[1]),
                'points': int(t_list[2]),
                'played_matches': int(t_list[3]),
                'win': int(t_list[4]),
                'draw': int(t_list[5]),
                'lost': int(t_list[6]),
                'favor': int(t_list[7]),
                'against': int(t_list[8])
            }
        return standings_dict

def get_standings_byteam(url, matchday_encode, seasonid):
    season = seasonid[-4:]
    season_past = int(season)-1
    season = str(season_past)+'/'+str(season)
    matchday = re.findall('\d', matchday_encode)
    matchday = ''.join(matchday)

    url_standings_req = requests.get(url)
    status = str(url_standings_req.status_code)
    # check status
    if status != '200':
        print()
        print('STATUS ERROR')
        print()
    else:
        pos = 1
        it = 0
        soup_standings = bs4.BeautifulSoup(url_standings_req.content, 'html.parser')
        '''STANDINGS LIST WITH INDEX'''
        standings_list = soup_standings.find(id='col-clasificacion')
        standings_raw = standings_list.find_all('a')
        standings = {}
        for s in standings_raw:
            s_clean = cleanhtml(str(s))
            standings.update({pos: s_clean})
            pos = pos + 1
        '''ALL STANDINGS INFO'''
        standings_info = standings_list.find_all('tr')
        del standings_info[0]
        standings_dict = {}
        standings_dict['season'] = season
        standings_dict['matchday'] = int(matchday)
        for t in standings_info:
            t_clean = cleanhtml(str(t))
            pattern_deletefreespace = re.compile(r'\s+')
            t_separated = re.sub(pattern_deletefreespace, ' ', t_clean)
            t_composed_teams = composed_team_name(t_separated)
            t_list = t_composed_teams.split()
            position = 'pos_' + t_list[0]
            standings_dict[position] = {
                'position': int(t_list[0]),
                'team_name': str(t_list[1]),
                'points': int(t_list[2]),
                'played_matches': int(t_list[3]),
                'win': int(t_list[4]),
                'draw': int(t_list[5]),
                'lost': int(t_list[6]),
                'favor': int(t_list[7]),
                'against': int(t_list[8])
            }
            standings_dict_byteam = {}
            standings_dict_byteam['season'] = season
            standings_dict_byteam['matchday'] = int(matchday)
            standings_dict_byteam['team_name'] = str(t_list[1])
            standings_dict_byteam['position'] = int(t_list[0])
            standings_dict_byteam['points'] = int(t_list[2])
            standings_dict_byteam['played_matches'] = int(t_list[3])
            standings_dict_byteam['win'] = int(t_list[4])
            standings_dict_byteam['draw'] = int(t_list[5])
            standings_dict_byteam['lost'] = int(t_list[6])
            standings_dict_byteam['goals_favor'] = int(t_list[7])
            standings_dict_byteam['goals_against'] = int(t_list[8])


            mongo_connect_standings(standings_dict_byteam)
            print(standings_dict_byteam['position'])